github
======

Add the relevant files to make your package ready for hosting on GitHub_. This
option is the base for all web related options. It depends on the :doc:`../git/main`
option for the local side of version management.

This option takes care of the local package side of github (e.g. .gitignore file)
but you still need to register your project on github. See :doc:`github_tutorial`
for example.

.. _GitHub: https://github.com/
